# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial project structure
- Core validation functionality
- Policy rule engine
- CLI with rich text output
- JSON output format
- Basic rule plugins (SQL write detection, secret detection)
- JSON schema validation
- Bounds checking
- Cycle detection

## [0.0.1] - 2023-04-27

### Added
- Initial alpha release 